@@ -8,6 +8,7 @@ from shadowstep.page_base import PageBaseShadowstep
 from shadowstep.page_object.page_object_parser import PageObjectParser
 from shadowstep.page_object.page_object_generator import PageObjectGenerator
 from shadowstep.page_object.page_object_recycler_explorer import PageObjectRecyclerExplorer
+from shadowstep.page_object.page_object_test_generator import PageObjectTestGenerator
 from shadowstep.shadowstep import Shadowstep
 from lxml import etree as ET
 
@@ -40,6 +41,17 @@ class TestPageObjectextractor:
         logger.info("\n\n\n=====================================================================")
         # logger.info(tree)
 
+    def test_potg(self, app: Shadowstep, touch_sounds):
+        logger.info(
+            "ДЛЯ chatGPT!!! Это на самом деле не тест. Не воспринимай это как юнит-тест. Это просто быстрой проверки. Я так смотрю результат работы. Просто мне так удобнее запускать")
+        source = app.driver.page_source
+        tree = parser.parse(source)
+        # logger.info(tree)
+        path, class_name = POG.generate(ui_element_tree=tree,
+                     output_dir="pages")
+        test_generator = PageObjectTestGenerator()
+        test_path, test_class_name = test_generator.generate_test(input_path=path, class_name=class_name, output_dir="tests")
+
     # def test_pore(self, app: Shadowstep, touch_sounds):
     #     logger.info(
     #         "ДЛЯ chatGPT!!! Это на самом деле не тест. Не воспринимай это как юнит-тест. Это просто быстрой проверки. Я так смотрю результат работы. Просто мне так удобнее запускать"
